@@ -6,7 +6,9 @@ module_path=os.path.join(pkg_data_path,'modules')
 class CLI:
     @classmethod
     def export(self,path='./'):
-        shutil.copy(module_path,path)
+        if os.path.exists(path):
+            path=os.path.join(path,'modules')
+        shutil.copytree(module_path,path)
 
 
 
